### R code from vignette source 'mhw_2'

###################################################
### code chunk number 1: mhw_2.Rnw:18-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70)
par(mfrow=c(1,1))
# setwd("~/data/Journal/Monographs/StatsMonographs/MHW_Sweave/")
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 2: mhw_2.Rnw:44-50
###################################################
with(mhw, plot(c, r, type="n", xlab="column", ylab="row", ylim=c(20,1),
     main="Layout of the Mercer-Hall uniformity trial"))
abline(v=1:25, lty=1, col="darkgray")
abline(h=1:20, lty=1, col="darkgray")
   # rownames() gives the plot number
with(mhw, text(c,r, rownames(mhw), cex=.5))


###################################################
### code chunk number 3: mhw_2.Rnw:61-67
###################################################
with(mhw,
     plot(c, r, pch=21, col="black", bg="lightblue", ylim=c(20,1),
          xlab="column", ylab="row",
          main="Mercer-Hall uniformity trial",
          sub="Area of circles proportional to grain yield",
          cex=2*grain/max(grain)))


###################################################
### code chunk number 4: mhw_2.Rnw:74-79
###################################################
   # compute cutoff points for the octiles
(q8 <- quantile(mhw$grain, seq(0, 1, length=9)))
   # classify each observation
grain.c <- cut(mhw$grain, q8, include.lowest=T, labels=F)
sort(unique(grain.c))


###################################################
### code chunk number 5: mhw_2.Rnw:86-88
###################################################
   # look at the colour ramp: these are RRGGBB from 00 to FF (hex)
terrain.colors(8)


###################################################
### code chunk number 6: mhw_2.Rnw:109-115
###################################################
with(mhw,
     plot(c, r, pch=20, cex=2, bg="lightblue", ylim=c(20,1),
          xlab="column", ylab="row",
          main="Mercer-Hall uniformity trial",
          sub="Colour of circles from low yield (green) to high (gray)",
          col=terrain.colors(8)[grain.c]))


###################################################
### code chunk number 7: mhw_2.Rnw:126-133
###################################################
require(sp)
plot(wireframe(grain ~ r + c, data=mhw, drape=T,
               aspect=c(1,.2), col.regions=bpy.colors(128),
               main="Grain yield, lb. per plot",
               screen= c(z=30, x=-60),
               xlab="N to S", ylab="W to E",
               sub="Looking SE from NW corner of field"))


###################################################
### code chunk number 8: mhw_2.Rnw:142-148
###################################################
plot(wireframe(grain ~ r + c, data=mhw, drape=T,
               aspect=c(1,.08), col.regions=bpy.colors(128),
               main="Grain yield, lb. per plot",
               screen= c(z=270, x=-75), zlab="",
               xlab="N to S", ylab="W to E",
               sub="Looking N from S end of field"))


###################################################
### code chunk number 9: mhw_2.Rnw:166-169
###################################################
ha2ac <- 2.471054
ft2m <- .3048
(field.area <- 10000/ha2ac)


###################################################
### code chunk number 10: mhw_2.Rnw:173-177
###################################################
(plot.area <- field.area/500)
(plot.len <- sqrt(field.area)/20)
(plot.wid <- sqrt(field.area)/25)
rm(ha2ac, ft2m, field.area)


###################################################
### code chunk number 11: mhw_2.Rnw:184-188
###################################################
(tot.len <- plot.len*20)
(tot.wid <- plot.wid*25)
tot.len * tot.wid
rm(tot.len, tot.wid)


###################################################
### code chunk number 12: mhw_2.Rnw:200-202
###################################################
plot.wid/2
plot.len/2


###################################################
### code chunk number 13: mhw_2.Rnw:207-213
###################################################
nrow <- length(unique(mhw$r))
ncol <- length(unique(mhw$c))
sx <- seq(plot.wid/2, plot.wid/2+(ncol-1)*plot.wid, length=ncol)
sy <- seq(plot.len/2+(nrow-1)*plot.len, plot.len/2, length=nrow)
xy <- expand.grid(x=sx, y=sy)
rm(nrow, ncol, sx, sy)


###################################################
### code chunk number 14: mhw_2.Rnw:233-234
###################################################
require(sp); require(gstat); require(lattice)


###################################################
### code chunk number 15: mhw_2.Rnw:251-254
###################################################
mhw.sp <- mhw
coordinates(mhw.sp) <- xy
summary(mhw.sp)


###################################################
### code chunk number 16: mhw_2.Rnw:263-264
###################################################
save(mhw.sp, file="mhw_spatial.RData")


###################################################
### code chunk number 17: mhw_2.Rnw:282-296
###################################################
mhw.sp.pix <- as(mhw.sp,"SpatialPixelsDataFrame") 
f1 <- spplot(mhw.sp.pix, zcol="grain", cuts=8,
             col.regions=bpy.colors(64),
             main="Grain yield, lb. per plot", key.space="right")
f2 <- spplot(mhw.sp.pix, zcol="straw", cuts=8,
             col.regions=heat.colors(64),
             main="Straw yield, lb. per plot", key.space="right")
f3 <- spplot(mhw.sp.pix, zcol="gsr", cuts=8,
             col.regions=terrain.colors(64),
             main="Grain/Straw ratio", key.space="right")
print(f1, split=c(1,1,2,2), more=T)
print(f2, split=c(2,1,2,2), more=T)
print(f3, split=c(1,2,2,2), more=F)
rm(f1, f2, f3)


###################################################
### code chunk number 18: mhw_2.Rnw:304-310
###################################################
print(spplot(mhw.sp, zcol="grain", pch=15,
             cex=1.6*mhw$grain/max(mhw$grain), cuts=12,
             col.regions=bpy.colors(64),
             main="Grain yield, lb. per plot", 
             sub="Symbol size proportional to yield",
             key.space="right"))


###################################################
### code chunk number 19: mhw_2.Rnw:344-346
###################################################
with(mhw, sort(by(grain, r, mean), decreasing=FALSE))
with(mhw, sort(by(grain, c, mean), d=F))


###################################################
### code chunk number 20: mhw_2.Rnw:355-358
###################################################
  # show the rows horizontally
boxplot(grain ~ r, horizontal=T,  data=mhw, xlim=c(20,1),
        ylab="Row number", xlab="Grain yield, lb. per plot")


###################################################
### code chunk number 21: mhw_2.Rnw:360-363
###################################################
  # and the columns vertically
boxplot(grain ~ c, data=mhw,
        xlab="Column number", ylab="Grain yield, lb. per plot")


###################################################
### code chunk number 22: ts1
###################################################
ts1 <- lm(mhw.sp$grain ~ coordinates(mhw.sp))
summary(ts1)


###################################################
### code chunk number 23: mhw_2.Rnw:387-388
###################################################
rm(ts1)


###################################################
### code chunk number 24: mhw_2.Rnw:405-408
###################################################
v <- variogram(grain ~ 1, mhw.sp,
               cutoff=plot.wid*10, width=plot.wid)
print(plot(v, plot.numbers=T))


###################################################
### code chunk number 25: mhw_2.Rnw:434-437
###################################################
(vm <- vgm(0.15, "Sph", 5, 0.02))
(vm <- vgm(0.03, "Sph", 20, add.to=vm))
print(plot(v, model= vm, main="Estimated variogram model"))


###################################################
### code chunk number 26: mhw_2.Rnw:442-444
###################################################
(vmf <- fit.variogram(v, vm))
print(plot(v, model= vmf, main="Fitted variogram model"))


###################################################
### code chunk number 27: rm-ts1
###################################################
set.seed(4502)
head(mhw$grain)
head(s1 <- sample(mhw$grain, length(mhw$grain), replace=FALSE))
head(s2 <- sample(mhw$grain, length(mhw$grain), replace=FALSE))
head(s3 <- sample(mhw$grain, length(mhw$grain), replace=FALSE))
head(s1)
head(s2)
head(s3)


###################################################
### code chunk number 28: mhw_2.Rnw:489-503
###################################################
par(mfrow=c(2,2))
plot(mhw$c, mhw$r, pch=20, cex=2, bg="lightblue", ylim=c(20,1),
     xlab="column", ylab="row", main="Randomization 1",
     col=terrain.colors(8)[cut(s1, q8, include.lowest=T, labels=F)])
plot(mhw$c, mhw$r, pch=20, cex=2, bg="lightblue", ylim=c(20,1),
     xlab="column", ylab="row", main="Randomization 2",
     col=terrain.colors(8)[cut(s2, q8, include.lowest=T, labels=F)])
plot(mhw$c, mhw$r, pch=20, cex=2, bg="lightblue", ylim=c(20,1),
     xlab="column", ylab="row", main="Randomization 3",
     col=terrain.colors(8)[cut(s3, q8, include.lowest=T, labels=F)])
plot(mhw$c, mhw$r, pch=20, cex=2, bg="lightblue", ylim=c(20,1),
     xlab="column", ylab="row", main="Actual spatial distribution",
     col=terrain.colors(8)[grain.c])
par(mfrow=c(1,1))


###################################################
### code chunk number 29: mhw_2.Rnw:514-525
###################################################
s1 <- data.frame(s1); coordinates(s1) <- xy
s2 <- data.frame(s2); coordinates(s2) <- xy
s3 <- data.frame(s3); coordinates(s3) <- xy
pv <- plot(variogram(grain ~ 1, mhw.sp, cutoff=plot.wid*10,
                     width=plot.wid), main="Real")
p1 <- plot(variogram(s1 ~ 1, s1, cutoff=plot.wid*10,
                     width=plot.wid), main="Simulation 1")
p2 <- plot(variogram(s2 ~ 1, s2, cutoff=plot.wid*10,
                     width=plot.wid), main="Simulation 2")
p3 <- plot(variogram(s3 ~ 1, s3, cutoff=plot.wid*10,
                     width=plot.wid), main="Simulation 3")


###################################################
### code chunk number 30: mhw_2.Rnw:529-533
###################################################
print(p1, split=c(1,1,2,2), more=T)
print(p2, split=c(2,1,2,2), more=T)
print(p3, split=c(1,2,2,2), more=T)
print(pv, split=c(2,2,2,2), more=F)


###################################################
### code chunk number 31: mhw_2.Rnw:547-548
###################################################
rm(xy, q8, grain.c, s1, s2, s3, pv, p1, p2, p3)


###################################################
### code chunk number 32: mhw_2.Rnw:563-569
###################################################
mhw.sp.ns <- split(as.data.frame(mhw.sp), mhw.sp$in.north)
coordinates(mhw.sp.ns$T) <- ~x+y
coordinates(mhw.sp.ns$F) <- ~x+y
summary(mhw.sp.ns)
   # structure of just the N half
summary(mhw.sp.ns$T)


###################################################
### code chunk number 33: mhw_2.Rnw:578-580
###################################################
v.n <- variogram(grain ~ 1, mhw.sp.ns$T, cutoff=30)
v.s <- variogram(grain ~ 1, mhw.sp.ns$F, cutoff=30)


###################################################
### code chunk number 34: mhw_2.Rnw:585-592
###################################################
g.max = max(v$gamma, v.n$gamma, v.s$gamma)*1.2
plot.vgm.all <- plot(v, plot.numbers=T,
                     main="All", ylim=c(0,g.max))
plot.vgm.N <- plot(v.n, plot.numbers=T,
                   main="N half", ylim=c(0,g.max))
plot.vgm.S <- plot(v.s, plot.numbers=T,
                   main="S half", ylim=c(0,g.max))


###################################################
### code chunk number 35: mhw_2.Rnw:601-608
###################################################
   # split screen and show all three
   # must save the plots and then put them into one window
   # make a stretched window to compare all 3
#windows(h=8, w=20)  # might need smaller numbers on your screen
print(plot.vgm.all, split=c(1,1,3,1), more=T)
print(plot.vgm.N, split=c(2,1,3,1), more=T)
print(plot.vgm.S, split=c(3,1,3,1), more=F)


###################################################
### code chunk number 36: mhw_2.Rnw:615-622
###################################################
(vmS <- vgm(.14, "Sph", 20, .09))
(vmN <- vgm(.08, "Sph", 13 , .11))
(vmSf <- fit.variogram(v.s, vmN))
(vmNf <- fit.variogram(v.n, vmS))
plot.vgm.all <- plot(v, plot.numbers=T, main="All", model=vmf, ylim=c(0,g.max))
plot.vgm.N <- plot(v.n, plot.numbers=T, main="N half", model=vmNf, ylim=c(0,g.max))
plot.vgm.S <- plot(v.s, plot.numbers=T, main="S half", model=vmSf, ylim=c(0,g.max))


###################################################
### code chunk number 37: mhw_2.Rnw:627-630
###################################################
print(plot.vgm.all, split=c(1,1,3,1), more=T)
print(plot.vgm.N, split=c(2,1,3,1), more=T)
print(plot.vgm.S, split=c(3,1,3,1), more=F)


###################################################
### code chunk number 38: mhw_2.Rnw:638-640
###################################################
   # when done examining, clean up
rm(g.max, plot.vgm.all, plot.vgm.N, plot.vgm.S)


###################################################
### code chunk number 39: mhw_2.Rnw:650-651
###################################################
rm(v, v.n, v.s, vm, vmf, vmN, vmNf, vmS, vmSf)


###################################################
### code chunk number 40: mhw_2.Rnw:656-657
###################################################
rm(mhw.sp.ns)


