### R code from vignette source 'mhw_2a'

###################################################
### code chunk number 1: mhw_2a.Rnw:18-23
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70)
par(mfrow=c(1,1))
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 2: mhw_2a.Rnw:58-63
###################################################
mhw.rc <- mhw; coordinates(mhw.rc) <- ~r +c
v.map <- variogram(grain ~ 1, loc=mhw.rc, map=TRUE, cutoff=10, width=1)
summary(v.map$map$var1)
class(v.map)
plot(v.map, col.regions=bpy.colors(64), xlab="Row-wise (N-S) lag", ylab="Column-wise (W-E) lag")


###################################################
### code chunk number 3: mhw_2a.Rnw:79-84
###################################################
c0 <- var(mhw$grain)
v.map$map$cov <- c0  - v.map$map$var1
v.map$map$cor <- v.map$map$cov/c0
v.map$map$cor[which(is.na(v.map$map$cor))] <- 1
summary(v.map$map$cor)


###################################################
### code chunk number 4: mhw_2a.Rnw:92-100
###################################################
str(v.map$map@data)
n <- sqrt(length(v.map$map$cor))
v.map.mat <- matrix(v.map$map$cor, nrow=n, ncol=n)
plot(wireframe(v.map.mat, drape=T, aspect=c(1,.25),
               screen=c(z=225, x=-60), ylab="Column-wise (W-E) lag",
               xlab="Row-wise (N-S) lag", zlab="rho(h)",
               main="Autocorrelation surface, grain yields",
               col.regions=bpy.colors(72)))


###################################################
### code chunk number 5: mhw_2a.Rnw:122-125
###################################################
(c <- ceiling(n/2))
(v.map.mat[c:n,c])
(v.map.mat[c,c:n])


###################################################
### code chunk number 6: mhw_2a.Rnw:131-138
###################################################
par(mfrow=c(1,2))
str(v.map.mat)
plot(v.map.mat[c,c:n], type="h", ylim=c(-.2,1),main="Along columns (E-W)", ylab=expression(rho), col="blue", xlab="lag (rows)")
abline(h=0)
plot(v.map.mat[c:n,c], type="h", ylim=c(-.2,1), main="Along rows (N-S)", ylab=expression(rho), col="darkgreen", xlab="lag (columns)")
abline(h=0)
par(mfrow=c(1,1))


###################################################
### code chunk number 7: mhw_2a.Rnw:287-291
###################################################
# centre grain yields at zero
# organize as an array -- is this the right order?
m <- max(mhw$r); n <- max(mhw$c)
str(mhw.grain.matrix <- matrix(data=(mhw.rc$grain - mean(mhw.rc$grain)), nrow=m, ncol=n))


###################################################
### code chunk number 8: mhw_2a.Rnw:302-319
###################################################
## p, q lags in row, column direction
## positive column lags
cpq <- function(p, q, mat) {
  s <- 0
  for (i in 1:(m - p))
    for (j in 1:(n - q))
      s <- s + (mat[i,j]) * (mat[i+p, j+q])
  return((1/((m - p) * (n - q))) * s)
  }
## negative column lags
cpmq <- function(p, q, mat) {
  s <- 0
  for (i in 1:(m - p))
    for (j in (q+1):n)
      s <- s + (mat[i,j]) * (mat[i+p, j-q])
  return((1/((m - p) * (n - q))) * s)
  }


###################################################
### code chunk number 9: mhw_2a.Rnw:331-352
###################################################
## symmetry relations
## c(-p,q) = c(p, -q); c(-p, -q) = c(p, q)
## compute for the desired combination of lags
max.l <- 14; d <- 2*max.l + 1
ch <- matrix(0, d, d)
for (lag.r in 1:max.l)
  for (lag.c in 1:max.l) {
    ## c(p, -q) : lower-left
    ch[(max.l+1) + lag.r, (max.l +1) - lag.c] <- (cpmq(lag.r, lag.c, mhw.grain.matrix))
    ## c(-p, q) : upper-right
    ch[(max.l+1) - lag.r, (max.l+1) + lag.c] <- ch[(max.l+1) + lag.r, (max.l +1) - lag.c]
  }
for (lag.r in 0:max.l)
  for (lag.c in 0:max.l) {
    ## c(p, q) : lower-right, including centre
    ch[(max.l+1) + lag.r, (max.l+1) + lag.c] <- (cpq(lag.r, lag.c, mhw.grain.matrix))
    ## c(-p, -q) : upper-left
    ch[(max.l+1) - lag.r, (max.l+1) - lag.c] <- ch[(max.l+1) + lag.r, (max.l+1) + lag.c]
  }
ch <- ch/var(mhw$grain)
summary(as.vector(ch))


###################################################
### code chunk number 10: mhw_2a.Rnw:362-368
###################################################
plot(wireframe(ch, drape=T, aspect=c(1,.25),
               screen=c(z=225, x=-60), ylab="Column-wise (W-E) lag",
               xlab="Row-wise (N-S) lag", zlab="rho(h)",
               main="Autocorrelation surface, grain yields",
               auto.key=T,
               col.regions=bpy.colors(72)))


###################################################
### code chunk number 11: mhw_2a.Rnw:432-455
###################################################
grs <- function(r=0, s=0, t, L, cor.mat) {
  ## smoothing function: Bartlett lag window
  w <- function(x, y) {
    h <- sqrt(x^2 + y^2)
    return(ifelse(h <= L, 1 - (h/L),0))
  }
  max.p <- dim(cor.mat)[1]; max.q <- dim(cor.mat)[2]
  centre.p <- ((max.p-1)/2)+1; centre.q <- ((max.q-1)/2)+1
  sum <- 0
  for (q in -L:L) {
    if (centre.q+q+1 > max.q) break
    for (p in -L:L) {
      if (centre.p+p+1 > max.p) break
      ## cor.mat is dimensioned 1.. 2L+1
      ## p, q are dimensions -L...0... L
      ## so add offset to the matrix subscripts, from centre out
      s1 <- (cor.mat[centre.p+p,centre.q+q] * w(p,q) * cos((pi/t)*((r*p) + (s*q))))
#      print(paste("x=",centre.p+p+L+1, "y=",centre.q+q+L+1, "s1=",round(s1,4)))
      sum <- sum + s1
    }
  }
  return(sum/(4*pi^2))
}


###################################################
### code chunk number 12: mhw_2a.Rnw:465-472
###################################################
# theta <- 50; dens <- rep(0, 2*theta+1)
theta <- 50; dens <- rep(0, theta+1)
#for (r in -theta:theta)
# for (r in 0:theta)
#  dens[theta+r+1] <- grs(r, 0, t=theta, L=10 ,cor.mat=ch)
for (s in 0:theta)
  dens[s+1] <- grs(0, s, t=theta, L=10 ,cor.mat=ch)


###################################################
### code chunk number 13: mhw_2a.Rnw:487-491
###################################################
plot(dens ~ seq(0, 0.5, length=theta+1), type="p", main="Spectral density, W-E", sub="window size 10", ylab="density", xlab="frequency, cycles", pch=20, cex=0.6)
dens.smooth <- spline(dens)
lines(dens.smooth$y ~ seq(0, 0.5, length=length(dens.smooth$x)), lty=1)
grid()


###################################################
### code chunk number 14: mhw_2a.Rnw:505-509
###################################################
l.s <- seq(4,14,by=2)
theta <- 50
dens <- matrix(rep(0, length(l.s)*(theta+1)),
               nrow=length(l.s))


###################################################
### code chunk number 15: mhw_2a.Rnw:517-522
###################################################
for (i in 1:length(l.s)) {
  for (s in 0:theta) {
    dens[i,s+1] <- grs(0, s, theta, l.s[i] ,ch)
  }
}


###################################################
### code chunk number 16: mhw_2a.Rnw:531-538
###################################################
plot(dens[1,] ~ seq(0, 0.5, length=theta+1), type="n", main="Spectral density, W-E", ylab="density", xlab="frequency, cycles", ylim=c(min(0,dens), max(dens)*1.1))
for (i in 1:length(l.s)) {
  dens.smooth <- spline(dens[i,])
  lines(dens.smooth$y ~ seq(0, 0.5, length=length(dens.smooth$x)), lty=i)
  text(0,max(dens[i,]),paste("L =",l.s[i],sep=""), pos=3)
}
grid()


###################################################
### code chunk number 17: mhw_2a.Rnw:564-571
###################################################
theta <- 50; dens <- rep(0, theta+1)
for (r in 0:theta)
  dens[r+1] <- grs(r, 0, t=theta, L=10 ,cor.mat=ch)
plot(dens ~ seq(0, 0.5, length=theta+1), type="p", main="Spectral density, N-S", sub="window size 10", ylab="density", xlab="frequency, cycles", pch=20, cex=0.6)
dens.smooth <- spline(dens)
lines(dens.smooth$y ~ seq(0, 0.5, length=length(dens.smooth$x)), lty=1)
grid()


###################################################
### code chunk number 18: mhw_2a.Rnw:589-600
###################################################
theta=25
dens <- matrix(rep(0, (theta+1)^2), nrow=theta+1)
for (s in 0:theta)
  for (r in 0:theta)
    dens[r+1,s+1] <- grs(r, s, theta, 10 ,ch)
wireframe(dens, drape=T, aspect=c(1,.35), screen=c(z=225, x=-60),
          xlab="N-S frequency",
          ylab="E-W frequency", zlab="density",
          auto.key=T,
          col.regions=topo.colors(72)
          )


###################################################
### code chunk number 19: mhw_2a.Rnw:608-609
###################################################
rm(mhw.rc, v.map, c0, v.map.mat, m, n, c, max.l, lag.r, lag.c, r, s, theta, dens, dens.smooth, l.s, grs, ch)


