### R code from vignette source 'mhw_2g'

###################################################
### code chunk number 1: mhw_2g.Rnw:18-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70)
par(mfrow=c(1,1))
# setwd("~/data/Journal/Monographs/StatsMonographs/MHW_Sweave/")
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 2: mhw_2g.Rnw:34-35
###################################################
coef(model.straw.grain <- lm(straw ~ grain, data=mhw.sp))


###################################################
### code chunk number 3: mhw_2g.Rnw:54-59
###################################################
mhw.sp$msg.res <- residuals(model.straw.grain)
mhw.sp.pix <- as(mhw.sp,"SpatialPixelsDataFrame")
spplot(mhw.sp.pix, zcol="msg.res", col.regions=bpy.colors(64),
       main="Linear model residuals",
       sub="straw ~ grain, lb. per plot")


###################################################
### code chunk number 4: mhw_2g.Rnw:75-77
###################################################
vr <- variogram(msg.res ~ 1, loc=mhw.sp, cutoff=plot.wid*10, width=plot.wid)
plot(vr, pl=T, pch=20, cex=1.5)


###################################################
### code chunk number 5: mhw_2g.Rnw:93-95
###################################################
(vgmr <- fit.variogram(vr, model=vgm(0.15, "Sph", 20, 0.05)))
plot(vr, model=vgmr, pch=20, cex=1.5)


###################################################
### code chunk number 6: mhw_2g.Rnw:247-248
###################################################
dnorm(x=c(-1.96,-1,-0.5,0,.5,1,1.96), mean=0, sd=1)


###################################################
### code chunk number 7: mhw_2g.Rnw:254-256
###################################################
s <- seq(0.4, 2, by=.2)
data.frame(sd=s, p=dnorm(x=1, mean=0, sd=s))


###################################################
### code chunk number 8: mhw_2g.Rnw:269-280
###################################################
tmp <- rainbow(length(s))
curve(dnorm(x, mean=0, s[1]), -3, 3, col=tmp[1],
      main="Normal probability density",
      sub="Varying the standard deviation",
      ylab="density",xlab="residual")
for (i in 2:length(s))
     curve(dnorm(x, mean=0, sd=s[i]), -3, 3,
           col=tmp[i], add=T)
grid()
abline(v=1, lty=2)
legend(-3, 1, s, lty=1, col=tmp)


###################################################
### code chunk number 9: mhw_2g.Rnw:402-409
###################################################
like <- function(beta0, beta1, sigma, x, y) {
	s2 <- sigma^2; n <- length(y)
        # compute fits given the coefficients
        pred <- beta0 + beta1 * x
	loglike <- -(n/2)*(log(2*pi)) - (n/2)*(log(s2)) - (1/(2*s2))*(sum((y-pred)^2))
	return(loglike)	
	} # like


###################################################
### code chunk number 10: mhw_2g.Rnw:418-420
###################################################
coefficients(lm(straw ~ grain, data=mhw))
summary(lm(straw ~ grain, data=mhw))$sigma


###################################################
### code chunk number 11: mhw_2g.Rnw:425-433
###################################################
coef <- round(coefficients(lm(straw ~ grain, data=mhw)),5)
(beta0 <- coef[1]*seq(0.9,1.1,by=.02))
(beta1 <- coef[2]*seq(0.9,1.1,by=.02))
(sigma <- round(summary(lm(straw ~ grain, data=mhw))$sigma,5)*seq(0.9,1.1,by=.02))
beta <- expand.grid(beta0=beta0, beta1=beta1, sigma=sigma)
beta$loglik <- 0
dim(beta)
rm(coef, beta0, beta1, sigma)


###################################################
### code chunk number 12: mhw_2g.Rnw:442-446
###################################################
for (i in 1:length(beta$loglik))
  beta$loglik[i] <- like(beta[i,"beta0"], beta[i,"beta1"], beta[i,"sigma"], mhw$grain, mhw$straw)
summary(beta$loglik)
(beta.mle <- beta[which.max(beta$loglik),])


###################################################
### code chunk number 13: mhw_2g.Rnw:462-479
###################################################
par(mfrow=c(1,3))
tmp <- beta[(beta$sigma==beta.mle$sigma),]
tmp <- tmp[(tmp$beta1==beta.mle$beta1),]
plot(tmp$loglik ~ tmp$beta0, type="b", xlab="intercept", ylab="log-likelihood", main="Constant slope, s.d.")
grid()
abline(v=beta.mle$beta0)
tmp <- beta[(beta$sigma==beta.mle$sigma),]
tmp <- tmp[(tmp$beta0==beta.mle$beta0),]
plot(tmp$loglik ~ tmp$beta1, type="b", xlab="slope", ylab="log-likelihood", main="Constant intercept, s.d.")
grid()
abline(v=beta.mle$beta1)
tmp <- beta[(beta$beta1==beta.mle$beta1),]
tmp <- tmp[(tmp$beta0==beta.mle$beta0),]
plot(tmp$loglik ~ tmp$sigma, type="b", xlab="s.d.", ylab="log-likelihood", main="Constant intercept, slope")
grid()
abline(v=beta.mle$sigma)
par(mfrow=c(1,3))


###################################################
### code chunk number 14: mhw_2g.Rnw:487-489
###################################################
tmp <- beta[(beta$sigma==beta.mle$sigma),]
wireframe(loglik ~ beta0 + beta1, data=tmp, aspect=c(1,.5), drape=T, main="Log-likelihood, Constant s.d.")


###################################################
### code chunk number 15: mhw_2g.Rnw:502-503
###################################################
rm(like, beta, i, beta.mle, tmp)


###################################################
### code chunk number 16: mhw_2g.Rnw:673-675
###################################################
require(nlme)
help(gls)


###################################################
### code chunk number 17: mhw_2g.Rnw:692-700
###################################################
system.time(
            model.gls.straw.grain <-
            gls(model=straw ~ grain,
                data=as.data.frame(mhw.sp),
                correlation=corSpher(
                  value=c(vgmr[2,"range"],vgmr[1,"psill"]),
                  form=~x+y, nugget=T))
            )


###################################################
### code chunk number 18: mhw_2g.Rnw:707-708
###################################################
summary(model.gls.straw.grain)


###################################################
### code chunk number 19: mhw_2g.Rnw:731-733
###################################################
coefficients(model.gls.straw.grain)
coefficients(model.straw.grain)


###################################################
### code chunk number 20: mhw_2g.Rnw:753-757
###################################################
logLik(model.gls.straw.grain)
logLik(model.straw.grain)
AIC(model.gls.straw.grain)
AIC(model.straw.grain)


###################################################
### code chunk number 21: mhw_2g.Rnw:775-780
###################################################
plot(straw ~ grain, data=mhw, pch=20,
     sub="black: OLS; red: GLS")
grid()
abline(model.straw.grain)
abline(model.gls.straw.grain, col="red")


###################################################
### code chunk number 22: mhw_2g.Rnw:806-824 (eval = FALSE)
###################################################
## (vgmr.exp <- fit.variogram(vr, model=vgm(0.15, "Exp", 20*3, 0.05)))
## plot(vr, model=vgmr.exp)
## model.gls.straw.grain.exp <-
##   gls(model=straw ~ grain,
##       data=as.data.frame(mhw.sp),
##       correlation=corExp(
##         value=c(vgmr.exp[2,"range"],vgmr.exp[1,"psill"]),
##         form=~x+y, nugget=T))
## summary(model.gls.straw.grain.exp)
## coefficients(model.gls.straw.grain)-
##   coefficients(model.gls.straw.grain.exp)
## plot(straw ~ grain, data=mhw, pch=20,
##      sub="black: OLS; red: GLS (corSpher), green: GLS (corExp)")
## grid()
## abline(model.straw.grain)
## abline(model.gls.straw.grain, col="red")
## abline(model.gls.straw.grain.exp, col="darkgreen")
## rm(model.gls.straw.grain.exp, vgmr.exp)


###################################################
### code chunk number 23: mhw_2g.Rnw:888-889
###################################################
library(spgwr)


###################################################
### code chunk number 24: mhw_2g.Rnw:900-901
###################################################
(bw <- gwr.sel(straw ~ grain, data=mhw.sp, adapt=F, verbose=F))


###################################################
### code chunk number 25: mhw_2g.Rnw:912-914
###################################################
(vmf.gsr <- fit.variogram(v.gsr <- variogram(gsr ~ 1, loc=mhw.sp),
                          model=vgm(0.004, "Sph", 10, 0.002)))


###################################################
### code chunk number 26: mhw_2g.Rnw:929-930
###################################################
(gwr.sg <- gwr(straw ~ grain, data=mhw.sp, bandwidth=bw))


###################################################
### code chunk number 27: mhw_2g.Rnw:947-952
###################################################
gwr.coef <- as(gwr.sg$SDF,"SpatialPixelsDataFrame")
print(spplot(gwr.coef, zcol="grain",
             col.regions=bpy.colors(64),
             key.space="right", cuts=8,
             main="Slope: straw ~ grain"))


###################################################
### code chunk number 28: mhw_2g.Rnw:966-970
###################################################
print(spplot(gwr.coef, zcol="gwr.e",
             col.regions=bpy.colors(64),
             key.space="right", cuts=8,
             main="Slope: straw ~ grain"))


###################################################
### code chunk number 29: show-gwr-r-vgm
###################################################
vr.gwr <- variogram(gwr.e ~ 1,
                    loc=as(gwr.coef, "SpatialPointsDataFrame"),
                    cutoff=12, width=1)
plot(vr.gwr, plot.numbers=TRUE, pch=20)


###################################################
### code chunk number 30: mhw_2g.Rnw:987-991
###################################################
(vmf.r.gwr <- fit.variogram(vr.gwr,
                            model=vgm(0.10, "Sph", 8, 0.25)))
plot(vr.gwr, plot.numbers=TRUE, pch=20,
     model=vmf.r.gwr)


###################################################
### code chunk number 31: mhw_2g.Rnw:1005-1008
###################################################
mhw.sp$gls.res <- residuals(model.gls.straw.grain)
vr.gls <- variogram(gls.res ~ 1, loc=mhw.sp, cutoff= plot.wid*10, width=plot.wid)
(vmf.r.gls <- fit.variogram(vr.gls, model=vgm(0.1, "Sph", 5, 0.2)))


###################################################
### code chunk number 32: mhw_2g.Rnw:1014-1029
###################################################
ylim.plot=c(0, max(vr.gwr$gamma, vr.gls$gamma, vr$gamma))
plot(gamma ~ dist, data=vr.gwr, ylim=ylim.plot,
     type="b", lty=2, col="red", xlab="separation, m",
     ylab="semivariance, (lbs plot-1)^2",
     main="Regression model residuals")
lines(variogramLine(vmf.r.gwr, maxdist=max(vr.gwr$dist)),
      col="red")
points(gamma ~ dist, data=vr, type="b", lty=2, col="blue")
lines(variogramLine(vgmr, maxdist=max(vr.gwr$dist)),
      col="blue")
points(gamma ~ dist, data=vr.gls, type="b", lty=2, col="green")
lines(variogramLine(vmf.r.gls, maxdist=max(vr.gwr$dist)),
      col="green")
legend(20,0.15,c("OLS", "GLS", "GWR"), lty=1,
       col=c("blue","green","red"))


