### R code from vignette source 'mhw_2m'

###################################################
### code chunk number 1: ggplot-scatter
###################################################
library(ggplot2)
ggplot(data = mhw) +
    geom_point(aes(x = grain, y = straw, col = gsr))


###################################################
### code chunk number 2: grain.straw.ranges.cvs
###################################################
range(mhw$straw); range(mhw$grain)
round(sd(mhw$straw)/mean(mhw$straw),3)
round(sd(mhw$grain)/mean(mhw$grain),3)


###################################################
### code chunk number 3: mhw.normalize
###################################################
mhw.normal <- mhw[ , c("grain", "straw")]
normalize <- function(x) {
    return( (x - mean(x)) / sd(x) )
}
mhw.normal <- apply(mhw.normal,
                    MARGIN=2,
                    FUN=normalize)
summary(mhw.normal)


###################################################
### code chunk number 4: 5clusters
###################################################
set.seed(314)
(gs.cluster <- kmeans(mhw.normal,
                      centers = 5, nstart = 20))


###################################################
### code chunk number 5: ggplot-scatter-5
###################################################
mhw.sp$cluster.5 <- as.factor(gs.cluster$cluster)
ggplot(data = mhw.sp@data) +
    geom_point(aes(grain, straw, color=cluster.5)) +
    labs(colour="cluster.5")


###################################################
### code chunk number 6: show-5-zones
###################################################
g <- ggplot(data = mhw.sp@data) + 
    geom_point(aes(c, r, color=cluster.5), shape=15, size=5)
print(g)


###################################################
### code chunk number 7: color-brewer
###################################################
require(RColorBrewer)
display.brewer.all(type="qual")


###################################################
### code chunk number 8: show-5-zones-accent
###################################################
g + 
    scale_colour_brewer(name="cluster.5", palette="Accent")


###################################################
### code chunk number 9: nbclust
###################################################
library("NbClust")
opt.clust <- NbClust(mhw.normal, 
        distance = "euclidean", min.nc = 2, max.nc = 8,
    method = "kmeans", index = "silhouette")
summary(opt.clust)
print(opt.clust$All.index)
print(opt.clust$Best.nc)
plot(opt.clust$All.index, type="l",
     xlab="(Number of clusters - 1)",
     ylab="Average silhouette width")
grid()


###################################################
### code chunk number 10: 2clusters
###################################################
set.seed(314)
(gs.cluster.opt <- kmeans(mhw.normal,
                      centers=2, nstart = 20))


###################################################
### code chunk number 11: 2clust_scatter
###################################################
mhw.sp$cluster.2 <- as.factor(gs.cluster.opt$cluster)
ggplot(data = mhw.sp@data) +
    geom_point(aes(grain, straw, color=cluster.2)) +
    labs(colour="cluster.2")


###################################################
### code chunk number 12: 2clust_post
###################################################
g <- ggplot(data = mhw.sp@data) + 
    geom_point(aes(c, r, color=cluster.2), shape=15, size=5) +
    scale_colour_brewer(name="cluster.2", palette="Accent")
print(g)


###################################################
### code chunk number 13: spat.clust.setup
###################################################
mhw.normal <- cbind(mhw.normal, r = normalize(mhw$r))
mhw.normal <- cbind(mhw.normal, c = normalize(mhw$c))
summary(mhw.normal)


###################################################
### code chunk number 14: spat_clust_opt
###################################################
set.seed(314)
opt.clust <- NbClust(mhw.normal,
                     distance = "euclidean", min.nc = 2, max.nc = 8,
                     method = "kmeans", index = "silhouette")
print(opt.clust$All.index)
print(opt.clust$Best.nc)
plot(opt.clust$All.index, type="l",
     xlab="(Number of clusters - 1)",
     ylab="Average silhouette width",
     main="Spatial/feature space")
grid()


###################################################
### code chunk number 15: 2clusters
###################################################
set.seed(314)
(gs.cluster.opt <- kmeans(mhw.normal,
                      centers=2, nstart = 20))


###################################################
### code chunk number 16: spat_clust_2clust_scatter
###################################################
mhw.sp$cluster.2.sp <- as.factor(gs.cluster.opt$cluster)
ggplot(data = mhw.sp@data) +
    geom_point(aes(grain, straw, color=cluster.2.sp)) +
    labs(colour="cluster.2")


###################################################
### code chunk number 17: spat_clust_2clust_post
###################################################
g <- ggplot(data = mhw.sp@data) + 
    geom_point(aes(c, r, color=cluster.2.sp), shape=15, size=5) +
    scale_colour_brewer(name="cluster.2.sp", palette="Accent")
print(g)


